@@ -67,6 +67,10 @@ function(x, n=10, cumulative=FALSE) {
 
   if( n < 1 || n > NROW(x) ) stop("Invalid 'n'")
 
+  if(NCOL(x) > 1) {
+    stop("ncol(x) > 1. runSum only supports univariate 'x'")
+  }
+
   # Count NAs, ensure they're only at beginning of data.
   NAs <- sum(is.na(x))
   if( NAs > 0 ) {
@@ -116,6 +120,10 @@ function(x, n=10, cumulative=FALSE) {
 
   if( n < 1 || n > NROW(x) ) stop("Invalid 'n'")
 
+  if(NCOL(x) > 1) {
+    stop("ncol(x) > 1. runMin only supports univariate 'x'")
+  }
+
   # Count NAs, ensure they're only at beginning of data, then remove.
   NAs <- sum( is.na(x) )
   if( NAs > 0 ) {
@@ -173,6 +181,10 @@ function(x, n=10, cumulative=FALSE) {
   beg <- 1 + NAs
   len <- NROW(x) - NAs
 
+  if(NCOL(x) > 1) {
+    stop("ncol(x) > 1. runMax only supports univariate 'x'")
+  }
+
   # Initialize result vector 
   result <- double(NROW(x))
 
@@ -235,6 +247,10 @@ function(x, n=10, non.unique="mean", cumulative=FALSE) {
   beg <- 1 + NAs
   len <- NROW(x) - NAs
 
+  if(NCOL(x) > 1) {
+    stop("ncol(x) > 1. runMedian only supports univariate 'x'")
+  }
+
   # Non-unique median
   non.unique <- match.arg(non.unique, c('mean','max','min'))
   non.unique <- switch( non.unique, mean=0, max=1, min=-1 )
@@ -275,6 +291,11 @@ function(x, y, n=10, use="all.obs", sample=TRUE, cumulative=FALSE) {
 
   if( n < 1 || n > NROW(x) ) stop("Invalid 'n'")
 
+  if(NCOL(x) > 1 || NCOL(y) > 1) {
+    stop("ncol(x) > 1 or ncol(y) > 1.",
+         " runCov only supports univariate 'x' and 'y'")
+  }
+
   # "all.obs", "complete.obs", "pairwise.complete.obs"
 
   # Count NAs, ensure they're only at beginning of data, then remove.
@@ -368,6 +389,10 @@ function(x, n=10, center=NULL, stat="median",
 
   if( n < 1 || n > NROW(x) ) stop("Invalid 'n'")
 
+  if(NCOL(x) > 1) {
+    stop("ncol(x) > 1. runMAD only supports univariate 'x'")
+  }
+
   # Count NAs, ensure they're only at beginning of data, then remove.
   NAs <- sum( is.na(x) )
   if( NAs > 0 ) {
@@ -424,6 +449,10 @@ function(x, n=10) {
 
   if( n < 1 || n > NROW(x) ) stop("Invalid 'n'")
 
+  if(NCOL(x) > 1) {
+    stop("ncol(x) > 1. wilderSum only supports univariate 'x'")
+  }
+
   # Check for non-leading NAs
   # Leading NAs are handled in the C code
   x.na <- naCheck(x, n)
